@@ -86,21 +86,14 @@ def _order_matching(side: str,
                     # Calculate Cost
                     cash = traded_quant * Decimal(row.price) * mapping[side]["op"] / adjust_factor[contract_time]
 
-                    trade_list.append({"Side": side, "Order ID": f"{row.order_id}",
+                    trade_list.append({"delivery_start": orderbook['delivery_start'][0], "delivery_end": orderbook['delivery_end'][0],
+                                       "Side": side, "Order ID": f"{row.order_id}",
                                        "Quantity in MW": float(traded_quant),
                                        "Power in MW/h": float(traded_power),
                                        "Price": row["price"],
                                        "Cash": round(float(cash), 2),
                                        "Timestamp": timestamp} | ({"VWAP": round(vwap, 2)} if vwap else {}))
 
-                    # trade_list[len([*trade_list]) + 1] = {"Side": side,
-                    #                                       "Order ID": f"{row.order_id}",
-                    #                                       "Quantity in MW": float(traded_quant),
-                    #                                       "Power in MW/h": float(traded_power),
-                    #                                       "Price": row["price"],
-                    #                                       "Cash": round(float(cash), 2),
-                    #                                       "Timestamp": timestamp} | ({"VWAP": round(vwap, 2)} if vwap else {})
-
                     if row["order_id"] in [*exec_orders_list]:
                         # If Existing, Adjust Quantity
                         exec_orders_list[row["order_id"]] -= round(float(traded_quant), 1) * mapping[side]["op"]
@@ -383,4 +376,4 @@ def _order_matching_filter(df: pd.DataFrame, matched: dict[str, float]) -> None:
     # Check If Already Matched
     ind = df.order_id.isin(matched).values
     if True in ind:
-        df.loc[ind, "quantity"] -= round(matched[df.loc[ind, "order_id"].values[0]], 1)
+        df.loc[ind, "quantity"] -= [round(matched.get(key), 1) for key in df.loc[ind, "order_id"]]
